@@ -96,7 +96,7 @@ void gvir_config_domain_interface_set_model(GVirConfigDomainInterface *interface
                                                     "model", "type", model);
 }
 
-char *gvir_config_domain_interface_get_ifname(GVirConfigDomainInterface *interface)
+const char *gvir_config_domain_interface_get_ifname(GVirConfigDomainInterface *interface)
 {
     g_return_val_if_fail(GVIR_CONFIG_IS_DOMAIN_INTERFACE(interface), NULL);
 
@@ -115,7 +115,7 @@ GVirConfigDomainInterfaceLinkState gvir_config_domain_interface_get_link_state(G
                                                   GVIR_CONFIG_DOMAIN_INTERFACE_LINK_STATE_DEFAULT);
 }
 
-char *gvir_config_domain_interface_get_mac(GVirConfigDomainInterface *interface)
+const char *gvir_config_domain_interface_get_mac(GVirConfigDomainInterface *interface)
 {
     g_return_val_if_fail(GVIR_CONFIG_IS_DOMAIN_INTERFACE(interface), NULL);
 
@@ -123,7 +123,7 @@ char *gvir_config_domain_interface_get_mac(GVirConfigDomainInterface *interface)
                                             "mac", "address");
 }
 
-char *gvir_config_domain_interface_get_model(GVirConfigDomainInterface *interface)
+const char *gvir_config_domain_interface_get_model(GVirConfigDomainInterface *interface)
 {
     g_return_val_if_fail(GVIR_CONFIG_IS_DOMAIN_INTERFACE(interface), NULL);
 
@@ -135,32 +135,31 @@ G_GNUC_INTERNAL GVirConfigDomainDevice *
 gvir_config_domain_interface_new_from_tree(GVirConfigXmlDoc *doc,
                                            xmlNodePtr tree)
 {
-    xmlChar *type;
+    const char *type;
     GType gtype;
 
     type = gvir_config_xml_get_attribute_content(tree, "type");
     if (type == NULL)
         return NULL;
 
-    if (xmlStrEqual(type, (xmlChar*)"network")) {
+    if (g_str_equal(type, "network")) {
         gtype = GVIR_CONFIG_TYPE_DOMAIN_INTERFACE_NETWORK;
-    } else if (xmlStrEqual(type, (xmlChar*)"user")) {
+    } else if (g_str_equal(type, "user")) {
         gtype = GVIR_CONFIG_TYPE_DOMAIN_INTERFACE_USER;
-    } else if (xmlStrEqual(type, (xmlChar*)"bridge")) {
+    } else if (g_str_equal(type, "bridge")) {
         goto unimplemented;
-    } else if (xmlStrEqual(type, (xmlChar*)"direct")) {
+    } else if (g_str_equal(type, "direct")) {
         goto unimplemented;
-    } else if (xmlStrEqual(type, (xmlChar*)"server")) {
+    } else if (g_str_equal(type, "server")) {
         goto unimplemented;
-    } else if (xmlStrEqual(type, (xmlChar*)"mcast")) {
+    } else if (g_str_equal(type, "mcast")) {
         goto unimplemented;
-    } else if (xmlStrEqual(type, (xmlChar*)"ethernet")) {
+    } else if (g_str_equal(type, "ethernet")) {
         goto unimplemented;
     } else {
         g_debug("Unknown domain interface node: %s", type);
         return NULL;
     }
-    xmlFree(type);
 
     return GVIR_CONFIG_DOMAIN_DEVICE(gvir_config_object_new_from_tree(gtype, doc, NULL, tree));
 
