@@ -31,6 +31,10 @@
 
 #include "libvirt-glib/libvirt-glib.h"
 
+#if GLIB_CHECK_VERSION(2, 31, 0)
+#define g_mutex_new() g_new0(GMutex, 1)
+#endif
+
 struct gvir_event_handle
 {
     int watch;
