@@ -71,6 +71,21 @@ gvir_connection_error_quark(void)
     return g_quark_from_static_string("gvir-connection");
 }
 
+static GVirNodeInfo *
+gvir_node_info_copy(GVirNodeInfo *info)
+{
+    return g_slice_dup(GVirNodeInfo, info);
+}
+
+static void
+gvir_node_info_free(GVirNodeInfo *info)
+{
+    g_slice_free(GVirNodeInfo, info);
+}
+
+G_DEFINE_BOXED_TYPE(GVirNodeInfo, gvir_node_info,
+                    gvir_node_info_copy, gvir_node_info_free)
+
 static void gvir_connection_get_property(GObject *object,
                                          guint prop_id,
                                          GValue *value,
@@ -163,9 +178,18 @@ static void gvir_connection_class_init(GVirConnectionClass *klass)
                                                         G_PARAM_READABLE |
                                                         G_PARAM_WRITABLE |
                                                         G_PARAM_CONSTRUCT_ONLY |
-                                                        G_PARAM_STATIC_NAME |
-                                                        G_PARAM_STATIC_NICK |
-                                                        G_PARAM_STATIC_BLURB));
+                                                        G_PARAM_STATIC_STRINGS));
+
+    g_object_class_install_property(object_class,
+                                    PROP_HANDLE,
+                                    g_param_spec_boxed("handle",
+                                                       "Handle",
+                                                       "The connection handle",
+                                                       GVIR_TYPE_CONNECTION_HANDLE,
+                                                       G_PARAM_READABLE |
+                                                       G_PARAM_WRITABLE |
+                                                       G_PARAM_CONSTRUCT_ONLY |
+                                                       G_PARAM_STATIC_STRINGS));
 
     signals[VIR_CONNECTION_OPENED] = g_signal_new("connection-opened",
                  G_OBJECT_CLASS_TYPE(object_class),
@@ -205,19 +229,6 @@ static void gvir_connection_class_init(GVirConnectionClass *klass)
                  1,
                  GVIR_TYPE_DOMAIN);
 
-    g_object_class_install_property(object_class,
-                                    PROP_HANDLE,
-                                    g_param_spec_boxed("handle",
-                                                       "Handle",
-                                                       "The connection handle",
-                                                       GVIR_TYPE_CONNECTION_HANDLE,
-                                                       G_PARAM_READABLE |
-                                                       G_PARAM_WRITABLE |
-                                                       G_PARAM_CONSTRUCT_ONLY |
-                                                       G_PARAM_STATIC_NAME |
-                                                       G_PARAM_STATIC_NICK |
-                                                       G_PARAM_STATIC_BLURB));
-
     g_type_class_add_private(klass, sizeof(GVirConnectionPrivate));
 }
 
@@ -1118,6 +1129,9 @@ GVirDomain *gvir_connection_find_domain_by_name(GVirConnection *conn,
         GVirDomain *dom = value;
         const gchar *thisname = gvir_domain_get_name(dom);
 
+        if (thisname == NULL)
+            continue;
+
         if (strcmp(thisname, name) == 0) {
             g_object_ref(dom);
             g_mutex_unlock(priv->lock);
@@ -1149,6 +1163,9 @@ GVirStoragePool *gvir_connection_find_storage_pool_by_name(GVirConnection *conn,
         GVirStoragePool *pool = value;
         const gchar *thisname = gvir_storage_pool_get_name(pool);
 
+        if (thisname == NULL)
+            continue;
+
         if (strcmp(thisname, name) == 0) {
             g_object_ref(pool);
             g_mutex_unlock(priv->lock);
@@ -1336,3 +1353,37 @@ GVirStoragePool *gvir_connection_create_storage_pool
 
     return g_object_ref(pool);
 }
+
+/**
+ * gvir_connection_get_node_info:
+ * @conn: the connection
+ * @err: return location for any #GError
+ *
+ * Returns: (transfer full): the info
+ */
+GVirNodeInfo *gvir_connection_get_node_info(GVirConnection *conn,
+                                            GError **err)
+{
+    GVirConnectionPrivate *priv = conn->priv;
+    virNodeInfo info;
+    GVirNodeInfo *ret;
+
+    if (virNodeGetInfo(priv->conn, &info) < 0) {
+        gvir_set_error_literal(err, GVIR_CONNECTION_ERROR,
+                               0,
+                               "Unable to get node info");
+        return NULL;
+    }
+
+    ret = g_slice_new(GVirNodeInfo);
+    strncpy (ret->model, info.model, sizeof (ret->model));
+    ret->memory = info.memory;
+    ret->cpus = info.cpus;
+    ret->mhz = info.mhz;
+    ret->nodes = info.nodes;
+    ret->sockets = info.sockets;
+    ret->cores = info.cores;
+    ret->threads = info.threads;
+
+    return ret;
+}
