@@ -118,7 +118,14 @@ static void gvir_network_constructed(GObject *object)
 
     /* xxx we may want to turn this into an initable */
     if (virNetworkGetUUIDString(priv->handle, priv->uuid) < 0) {
-        g_error("Failed to get network UUID on %p", priv->handle);
+        virErrorPtr verr = virGetLastError();
+        if (verr) {
+            g_warning("Failed to get network UUID on %p: %s",
+                      priv->handle, verr->message);
+        } else {
+            g_warning("Failed to get network UUID on %p",
+                      priv->handle);
+        }
     }
 }
 
@@ -140,9 +147,7 @@ static void gvir_network_class_init(GVirNetworkClass *klass)
                                                        G_PARAM_READABLE |
                                                        G_PARAM_WRITABLE |
                                                        G_PARAM_CONSTRUCT_ONLY |
-                                                       G_PARAM_STATIC_NAME |
-                                                       G_PARAM_STATIC_NICK |
-                                                       G_PARAM_STATIC_BLURB));
+                                                       G_PARAM_STATIC_STRINGS));
 
     g_type_class_add_private(klass, sizeof(GVirNetworkPrivate));
 }
@@ -179,7 +184,8 @@ const gchar *gvir_network_get_name(GVirNetwork *network)
     const char *name;
 
     if (!(name = virNetworkGetName(priv->handle))) {
-        g_error("Failed to get network name on %p", priv->handle);
+        g_warning("Failed to get network name on %p", priv->handle);
+        return NULL;
     }
 
     return name;
